
-- Menu

function OpenMenu()
	GetPlayer():DoTaskInTime(0, ToggleMenu)
end

-- Spawning

local wormholeOne = nil
local wormholeTwo = nil

local function WormholeManager(inst)
	if not wormholeOne then			
		wormholeOne = inst
		
		print("Spawn another wormhole to complete the link.")
	elseif not wormholeTwo then
		wormholeTwo = inst
		
		wormholeOne.components.teleporter:Target(wormholeTwo)
		wormholeTwo.components.teleporter:Target(wormholeOne)
		
		wormholeOne = nil
		wormholeTwo = nil
		
		print("Wormholes linked.")
	end
end

-- Toggles

function ToggleGodMode()
	local inst = GetPlayer()
	
	if inst then 
		if inst.components.health:IsInvincible() then
			inst.components.health:SetInvincible(false)
			print("God mode disabled.")
		else
			inst.components.health:SetInvincible(true)
			print("God mode enabled.")
		end
	end
end

function ToggleRain()
	local seasonManager = GetSeasonManager()
		
	if seasonManager then
		if seasonManager:IsRaining() then
			seasonManager:StopPrecip()
			print("Stopping rain.")
		else
			seasonManager:StartPrecip()
			print("Starting rain.")
		end
	end
end

function ToggleSpeed(multiplier)
	local inst = GetPlayer()
	local default_runspeed = TUNING.WILSON_RUN_SPEED

	if inst then
		if inst.components.locomotor.runspeed > default_runspeed then
			inst.components.locomotor.runspeed = default_runspeed
		else
			inst.components.locomotor.runspeed = default_runspeed * (multiplier or 3)
		end
	end
end

function ToggleTimeScale()
	local timescaleIsIncreased = TheSim:GetTimeScale() > 1

	if timescaleIsIncreased then
		TheSim:SetTimeScale(1)
	else
		TheSim:SetTimeScale(4)
	end
end

function Freebuild()
	local inst = GetPlayer()
	
	if inst then
		if inst.components.builder.freebuildmode then
			inst.components.builder.freebuildmode = false
		else
			inst.components.builder.freebuildmode = true
		end

		inst:PushEvent("unlockrecipe")
	end
end


-- use this in the console instead of CharSelectScreen
function CharacterSelect(self)
	GetPlayer():DoTaskInTime(0, CharSelectScreen)
	end


-- Map

function MapHide()
	local ground = GetWorld()
	
	if ground then
		ground.Map:ResetVisited()
		
		print("Map hidden, save and reload.")
	end
end

function MapReveal()
	local minimap = TheSim:FindFirstEntityWithTag("minimap")
	
	if minimap then
		minimap.MiniMap:EnableFogOfWar(false)
		
		print("Map revealed.")
	end
end

-- Misc

function NextSeason()
	local seasonManager = GetSeasonManager()
	
	if seasonManager then
		if seasonManager:IsWinter() then
			seasonManager:StartSummer()
		else
			seasonManager:StartWinter()
		end
		
		print("Changing season to ", seasonManager:GetSeasonString(), ".")
	end
end

function NextDay()
	GetClock():MakeNextDay()
end

function NextPhase()
	GetClock():NextPhase()
end
-----------------------chromiumboy
-- Valid ground
local function IsValidTile(point)
    local ground = TheSim:FindFirstEntityWithTag("ground")
    
    if ground and point then
        local tile = ground.Map:GetTileAtPoint(point.x, point.y, point.z)
        if tile ~= GROUND.IMPASSIBLE then
            return true
        end
    end    

    return false
end

-- Spawn item
function Spawn(item, count)
    if not count then
        count = 1
    end
    
    if count > 40 then
        count = 40
    end
    
    if item then
        for v = 1, count, 1 do
            local spawneditem = SpawnPrefab(item)
            local pt = TheInput:GetWorldPosition()
            
            if IsValidTile(pt) then
                spawneditem.Physics:Teleport(pt.x, pt.y, pt.z)
            end
        end
    end
end

-- Give player item
function Give(item, count)
    if not count then
        count = 1
    end
    
    if count > 40 then
        count = 40
    end
    
    if item then
        for v = 1, count, 1 do
            local spawneditem = SpawnPrefab(item)
            if spawneditem.components.inventoryitem then
                GetPlayer().components.inventory:GiveItem(spawneditem)
            end
        end
    end
end
---------------------------chromiumboy

function Lightning()
	local seasonManager = GetSeasonManager()
	
	if seasonManager then
		local pt = Vector3(TheInput:GetWorldPosition():Get())
		seasonManager:DoLightningStrike(pt)
	end
end